/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package DataEntryBean;

/**
 *
 * @author Kaushik
 */
public class customerEnquiryBean {

    private String cif;
    private String cType;
    private String linkedAccount;
    private String tittle;
    private String fName;
    private String mName;
    private String lName;
    private String gName;
    private String add1;
    private String add2;
    private String add3;
    private String distname;
    private String cityname;
    private String statename;
    private String dob;
    private String gender;
    private String mNumber;
    private String idType;
    private String idNumber;
    private String file;
    private String sigUpld;
    private String religion;
    private String caste;
    private String insNo;
    private String insIssDate;
    private String insCom;
    private String emailId;

    public String getEmailId() {
        return emailId;
    }

    public void setEmailId(String emailId) {
        this.emailId = emailId;
    }
    

    public String getInsCom() {
        return insCom;
    }

    public void setInsCom(String insCom) {
        this.insCom = insCom;
    }

    public String getInsIssDate() {
        return insIssDate;
    }

    public void setInsIssDate(String insIssDate) {
        this.insIssDate = insIssDate;
    }

    public String getInsNo() {
        return insNo;
    }

    public void setInsNo(String insNo) {
        this.insNo = insNo;
    }

    public String getInsStatus() {
        return insStatus;
    }

    public void setInsStatus(String insStatus) {
        this.insStatus = insStatus;
    }
    private String insStatus;


    public String getCaste() {
        return caste;
    }

    public void setCaste(String caste) {
        if(caste.equalsIgnoreCase("1"))
        {
            this.caste = "General";
        }
        else if(caste.equalsIgnoreCase("2"))
        {
            this.caste = "SC";
        }
        else if(caste.equalsIgnoreCase("3"))
        {
            this.caste = "ST";
        }
        else if(caste.equalsIgnoreCase("4"))
        {
            this.caste = "Others";
        }
        else
        {
            this.caste =" ";
        }
    }

    public String getReligion() {
        return religion;
    }

    public void setReligion(String religion) {

        if(religion.equalsIgnoreCase("1"))
        {
            this.religion ="Hindu";
        }
        else if(religion.equalsIgnoreCase("2"))
        {
            this.religion ="Muslim";
        }
        else if(religion.equalsIgnoreCase("3"))
        {
            this.religion ="Christian";
        }
        else if(religion.equalsIgnoreCase("4"))
        {
            this.religion ="Sikh";
        }
        else if(religion.equalsIgnoreCase("5"))
        {
            this.religion ="Jain";
        }
        else if(religion.equalsIgnoreCase("6"))
        {
            this.religion ="Buddhist";
        }
        else if(religion.equalsIgnoreCase("7"))
        {
            this.religion ="Parsi";
        }
        else if(religion.equalsIgnoreCase("8"))
        {
            this.religion ="Others";
        }
        else
        {
            this.religion = " ";
        }
    }

    public String getSigUpld() {
        return sigUpld;
    }

    public void setSigUpld(String sigUpld) {
        this.sigUpld = sigUpld;
    }

    public String getFile() {
        return file;
    }

    public void setFile(String file) {
        this.file = file;
    }


    public String getUploadPath() {
        return uploadPath;
    }

    public void setUploadPath(String uploadPath) {
        this.uploadPath = uploadPath;
    }
    private String idIssueDate;
    private String idIssueAt;
    private String shareAmountDue;
    private String shareAmountPaid;
    private String block;
    private String uploadPath;
    private String uploadFlag;

    public String getUploadFlag() {
        return uploadFlag;
    }

    public void setUploadFlag(String uploadFlag) {
        this.uploadFlag = uploadFlag;
    }








    /**
     * @return the cif
     */
    public String getCif() {
        return cif;
    }

    /**
     * @param cif the cif to set
     */
    public void setCif(String cif) {
        this.cif = cif;
    }

    /**
     * @return the cType
     */
    public String getcType() {
        return cType;
    }

    /**
     * @param cType the cType to set
     */
    public void setcType(String cType) {
        this.cType = cType;
    }

    /**
     * @return the linkedAccount
     */
    public String getLinkedAccount() {
        return linkedAccount;
    }

    /**
     * @param linkedAccount the linkedAccount to set
     */
    public void setLinkedAccount(String linkedAccount) {
        this.linkedAccount = linkedAccount;
    }

    /**
     * @return the tittle
     */
    public String getTittle() {
        return tittle;
    }

    /**
     * @param tittle the tittle to set
     */
    public void setTittle(String tittle) {
        this.tittle = tittle;
    }

    /**
     * @return the fName
     */
    public String getfName() {
        return fName;
    }

    /**
     * @param fName the fName to set
     */
    public void setfName(String fName) {
        this.fName = fName;
    }

    /**
     * @return the mName
     */
    public String getmName() {
        return mName;
    }

    /**
     * @param mName the mName to set
     */
    public void setmName(String mName) {
        this.mName = mName;
    }

    /**
     * @return the lName
     */
    public String getlName() {
        return lName;
    }

    /**
     * @param lName the lName to set
     */
    public void setlName(String lName) {
        this.lName = lName;
    }

    /**
     * @return the gName
     */
    public String getgName() {
        return gName;
    }

    /**
     * @param gName the gName to set
     */
    public void setgName(String gName) {
        this.gName = gName;
    }

    /**
     * @return the add1
     */
    public String getAdd1() {
        return add1;
    }

    /**
     * @param add1 the add1 to set
     */
    public void setAdd1(String add1) {
        this.add1 = add1;
    }

    /**
     * @return the add2
     */
    public String getAdd2() {
        return add2;
    }

    /**
     * @param add2 the add2 to set
     */
    public void setAdd2(String add2) {
        this.add2 = add2;
    }

    /**
     * @return the add3
     */
    public String getAdd3() {
        return add3;
    }

    /**
     * @param add3 the add3 to set
     */
    public void setAdd3(String add3) {
        this.add3 = add3;
    }

    /**
     * @return the distname
     */
    public String getDistname() {
        return distname;
    }

    /**
     * @param distname the distname to set
     */
    public void setDistname(String distname) {
        this.distname = distname;
    }

    /**
     * @return the cityname
     */
    public String getCityname() {
        return cityname;
    }

    /**
     * @param cityname the cityname to set
     */
    public void setCityname(String cityname) {
        this.cityname = cityname;
    }

    /**
     * @return the statename
     */
    public String getStatename() {
        return statename;
    }

    /**
     * @param statename the statename to set
     */
    public void setStatename(String statename) {
        this.statename = statename;
    }

    /**
     * @return the dob
     */
    public String getDob() {
        return dob;
    }

    /**
     * @param dob the dob to set
     */
    public void setDob(String dob) {
        this.dob = dob;
    }

    /**
     * @return the gender
     */
    public String getGender() {
        return gender;
    }

    /**
     * @param gender the gender to set
     */
    public void setGender(String gender) {
        if((gender.equalsIgnoreCase("M")) ||((gender.equalsIgnoreCase("Male"))))
        {
            this.gender = "Male";
        }
        else if((gender.equalsIgnoreCase("F"))||((gender.equalsIgnoreCase("Female"))))
        {
            this.gender = "Female";
        }
        else if(gender.equalsIgnoreCase("O"))
        {
            this.gender = "Other";
        }
        else
        {
            this.gender = " ";
        }

    }

    /**
     * @return the mNumber
     */
    public String getmNumber() {
        return mNumber;
    }

    /**
     * @param mNumber the mNumber to set
     */
    public void setmNumber(String mNumber) {
        this.mNumber = mNumber;
    }

    /**
     * @return the idType
     */
    public String getIdType() {
        return idType;
    }

    /**
     * @param idType the idType to set
     */
    public void setIdType(String idType) {
        this.idType = idType;
    }

    /**
     * @return the idNumber
     */
    public String getIdNumber() {
        return idNumber;
    }

    /**
     * @param idNumber the idNumber to set
     */
    public void setIdNumber(String idNumber) {
        this.idNumber = idNumber;
    }

    /**
     * @return the idIssueDate
     */
    public String getIdIssueDate() {
        return idIssueDate;
    }

    /**
     * @param idIssueDate the idIssueDate to set
     */
    public void setIdIssueDate(String idIssueDate) {
        this.idIssueDate = idIssueDate;
    }

    /**
     * @return the idIssueAt
     */
    public String getIdIssueAt() {
        return idIssueAt;
    }

    /**
     * @param idIssueAt the idIssueAt to set
     */
    public void setIdIssueAt(String idIssueAt) {
        this.idIssueAt = idIssueAt;
    }

    /**
     * @return the shareAmountDue
     */
    public String getShareAmountDue() {
        return shareAmountDue;
    }

    /**
     * @param shareAmountDue the shareAmountDue to set
     */
    public void setShareAmountDue(String shareAmountDue) {
        this.shareAmountDue = shareAmountDue;
    }

    /**
     * @return the shareAmountPaid
     */
    public String getShareAmountPaid() {
        return shareAmountPaid;
    }

    /**
     * @param shareAmountPaid the shareAmountPaid to set
     */
    public void setShareAmountPaid(String shareAmountPaid) {
        this.shareAmountPaid = shareAmountPaid;
    }

    public String getBlock() {
        return block;
    }

    public void setBlock(String block) {
        this.block = block;
    }



}
